
% Plot the partitioning of the unit square given by Metis. This assumes the
% number of nodes is a perfect square; if not, life ends miserably.
% 
% I have run metis on a graph and saved the stdout from gpmetis to files named
% log.2, log.3, ....  From those I extracted the number of edges cut, and the
% numbers are put by hand into the array cutedges. That determines which
% files metisgraph.part.n are read for plotting. So if you want only powers of
% two you can use (e.g.)
% cutedges = [...
%   2 317
%   4 304
%   8 558];
%
% Beware that only 8 colors are used, and one of those is white. So if more
% than 8 partition sets are created, the colors will recycle. That can be
% fixed by using [r g b] triplets, but that is hardly worthwhile.
%

printem = false;  % Whether or not to create png files with the plots
colors = ['r', 'b', 'm', 'c', 'g', 'k', 'y', 'w'];
ncolors = length(colors);
marker = '+';

% For N = 128. Values come from output of gpmetis, saved in log files
%{
cutedges = [...
    2 134
    3 238
    4 304
    5 385
    6 444
    7 546
    8 558];
%}

% For N = 256. Values come from output of gpmetis, saved in log files
cutedges = [...
    2 317
    3 470
    4 593
    5 729
    6 959
    7 975
    8 1137];

setsizes = cutedges(:,1)'; % Gotta make this a row vector for the loop
cutsizes = cutedges(:,2);
p = 1;

for nsets = setsizes
    s = load(['metisgraph.part.' num2str(nsets) ]);

    n = length(s);
    N = sqrt(n);
    % nsets = length(unique(s));

    U = NaN*zeros(N,N);
    k = 1;
    for j = 1:N
        for i = 1:N
            U(i,j) = s(k);
            k = k + 1;
        end
    end

    figure 
    gh = gca;
    axis([0 N+1 0 N+1]);
    hold on
    for pset = 0:nsets-1
        I = find(U == pset);
        [x,y] = ind2sub([N N], I);
        fmtstr = [marker colors(1+mod(pset, ncolors))];
        plot(x, y, fmtstr)
    end
    hold off

    xxx = sprintf('Number of cut edges = %d', cutsizes(p));
    xlabel(xxx)
    title(['Metis Partitioning: ' num2str(nsets) ' Partition Sets'])
    axis('square')
    if printem
        fname = sprintf('square%d', nsets);
        print(fname, '-dpng')
    end
    p = p + 1;

end


